import React, { useState } from 'react';
import { AppMode } from '../types';
import './Instructions.css';

interface InstructionsProps {
  visible: boolean;
  onClose: () => void;
  onModeSelect: (mode: AppMode) => void;
}

export const Instructions: React.FC<InstructionsProps> = ({ 
  visible, 
  onClose,
  onModeSelect 
}) => {
  const [selectedMode, setSelectedMode] = useState<AppMode>('freestyle');

  const handleStart = () => {
    onModeSelect(selectedMode);
    onClose();
  };

  if (!visible) return null;

  return (
    <div className="instructions-overlay">
      <div className="instructions-panel" onClick={e => e.stopPropagation()}>
        <div className="instructions-header">
          <h2>Welcome to ✨ ZoomAccel ✨!</h2>
        </div>
        
        <div className="instructions-content">
          <p>
            This is a simulation that measures target acquisition performance with different zoom acceleration curves.
          </p>
          
          <div className="mode-selection">
            <h3>Select Mode</h3>
            <div className="radio-group">
              <label>
                <input
                  type="radio"
                  name="initial-mode"
                  value="freestyle"
                  checked={selectedMode === 'freestyle'}
                  onChange={() => setSelectedMode('freestyle')}
                />
                <span className="mode-label">Freestyle Mode</span>
                <p className="mode-description">Test and explore different zoom acceleration settings at your own pace.</p>
              </label>
              <label>
                <input
                  type="radio"
                  name="initial-mode"
                  value="study"
                  checked={selectedMode === 'study'}
                  onChange={() => setSelectedMode('study')}
                />
                <span className="mode-label">Study Mode</span>
                <p className="mode-description">Complete 25 targets with each preset curve (A, B, C, D) for structured data collection.</p>
              </label>
            </div>
          </div>

          <h3>Instructions</h3>
          <ul>
            <li>
              Click the green targets as quickly and accurately as possible
            </li>
            <li>
              Use <span className="keyboard-shortcut">Ctrl + Scroll</span> or <span className="keyboard-shortcut">⌘ + Scroll</span> to zoom
            </li>
            <li>
              Click and drag to pan the view
            </li>
            <li>
              Toggle zoom acceleration and customize the curve in Settings <span className="keyboard-shortcut">⚙️</span>
            </li>
            <li>
              View your performance history and export results using the History panel <span className="keyboard-shortcut">📊</span>
            </li>
          </ul>

          <div className="warning-message">
            <h3>⚠️ Important</h3>
            <p>
              Resizing your browser window will reset the target positions to match the new window dimensions. 
              Please avoid resizing during Study Mode to maintain consistent test conditions.
            </p>
          </div>

          <p>
            Try different acceleration curves to find what works best for you!
          </p>
        </div>

        <div className="instructions-footer">
          <button className="got-it-button" onClick={handleStart}>
            Start {selectedMode === 'freestyle' ? 'Freestyle Mode' : 'Study Mode'}
          </button>
        </div>
      </div>
    </div>
  );
}; 