import { clamp } from './math';
import { interpolateCurveValue } from './settings';
import { CONSTANTS } from '../types';

export const calculateAccelerationFactor = (
	wheelSamples: number[],
	accelerationCurve: number[],
	enabled: boolean
): number => {
	if (!enabled || !wheelSamples || wheelSamples.length === 0 || !accelerationCurve) return 1;

	// Calculate average speed in one pass
	const averageSpeed = wheelSamples.reduce((sum, val) => sum + Math.abs(val), 0) / wheelSamples.length;
	const normalizedSpeed = clamp(averageSpeed / 100, 0, 2);
	return interpolateCurveValue(accelerationCurve, normalizedSpeed);
};

export const processWheelDelta = (
	rawDelta: number,
	maxDelta = 100
): number => {
	return clamp(rawDelta, -maxDelta, maxDelta);
};

export const updateWheelSamples = (
	samples: number[],
	newValue: number
): number[] => {
	const newSamples = samples.length >= CONSTANTS.MOUSE_WHEEL_SAMPLES 
		? [...samples.slice(1), Math.abs(newValue)]
		: [...samples, Math.abs(newValue)];
	return newSamples;
};
