import { AccelerationSettings, CONSTANTS } from '../types';
import { lerp } from './math';

export const updateSettingsCurve = (
	settings: AccelerationSettings,
	index: number,
	value: number
): AccelerationSettings => {
	const currentCurve = settings.accelerationCurve ?? new Array(CONSTANTS.NUM_CURVE_POINTS).fill(1);
	return {
		...settings,
		accelerationCurve: currentCurve.map((v, i) => i === index ? value : v)
	};
};

export const createDefaultSettings = (): AccelerationSettings => ({
	enabled: false,
	accelerationCurve: new Array(CONSTANTS.NUM_CURVE_POINTS).fill(1)
});

export const interpolateCurveValue = (
	accelerationCurve: number[],
	normalizedSpeed: number
): number => {
	if (!accelerationCurve || accelerationCurve.length === 0) return 1;
	
	const curveIndex = normalizedSpeed * (accelerationCurve.length - 1);
	const lowerIndex = Math.floor(curveIndex);
	const upperIndex = Math.min(accelerationCurve.length - 1, Math.ceil(curveIndex));
	const interpolationFactor = curveIndex - lowerIndex;
	return lerp(
		accelerationCurve[lowerIndex], 
		accelerationCurve[upperIndex], 
		interpolationFactor
	);
};
