import { Round, Stats, AccelerationSettings } from '../types';

interface StorageState {
  rounds: Round[];
  stats: Stats;
  settings: AccelerationSettings;
}

const STORAGE_KEY = 'zoomaccell_state';

export const saveState = (state: StorageState): void => {
  try {
    localStorage.setItem(STORAGE_KEY, JSON.stringify(state));
  } catch (error) {
    console.error('Failed to save state:', error);
  }
};

export const loadState = (): StorageState | null => {
  try {
    const savedState = localStorage.getItem(STORAGE_KEY);
    return savedState ? JSON.parse(savedState) : null;
  } catch (error) {
    console.error('Failed to load state:', error);
    return null;
  }
};

export const exportToCSV = (rounds: Round[]): void => {
  const headers = ['Round', 'Time (ms)', 'Misclicks', 'Acceleration', 'Preset', 'Zoom-In Time (ms)', 'Zoom-Out Time (ms)', 'Timestamp'];
  const rows = rounds.map((round, index) => [
    index + 1,
    round.timeSpent,
    round.misclicks,
    round.accelerationEnabled ? 'On' : 'Off',
    round.preset || 'None',
    round.zoomInTime || 0,
    round.zoomOutTime || 0,
    new Date(round.timestamp).toISOString()
  ]);

  const csvContent = [
    headers.join(','),
    ...rows.map(row => row.join(','))
  ].join('\n');

  const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
  const link = document.createElement('a');
  link.href = URL.createObjectURL(blob);
  link.download = `zoom_acceleration_results_${new Date().toISOString()}.csv`;
  link.click();
}; 